// ---------------------------------------------------------------------------
// Preprocessor.java
// Preprocessor interface for LTL formulas.
// $Id: Preprocessor.java,v 1.1 2022/08/24 12:47:14 schreine Exp $
//
// Author: Ágoston Sütő <agoston.suetoe@jku.at>
// Copyright (C) 2021-, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.jku.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package riscal.ltl;

import riscal.semantics.Types;
import riscal.syntax.AST;

public interface Preprocessor<T> {
	T translate(AST.LTL.LetLTL ast, Types.Context context);
	T translate(AST.LTL.LetParLTL ast, Types.Context context);
	T translate(AST.LTL.ForallLTL ast, Types.Context context);
	T translate(AST.LTL.ExistsLTL ast, Types.Context context);

	T translate(AST.LTL.StateLTL ast, Types.Context context);
	T translate(AST.LTL.ActionLTL ast, Types.Context context);

	T translate(AST.LTL.NotLTL ast, Types.Context context);
	T translate(AST.LTL.AndLTL ast, Types.Context context);
	T translate(AST.LTL.OrLTL ast, Types.Context context);
	T translate(AST.LTL.ImpliesLTL ast, Types.Context context);
	T translate(AST.LTL.EquivLTL ast, Types.Context context);
	T translate(AST.LTL.IfThenElseLTL ast, Types.Context context);

	T translate(AST.LTL.NextLTL ast, Types.Context context);
	T translate(AST.LTL.FinallyLTL ast, Types.Context context);
	T translate(AST.LTL.GloballyLTL ast, Types.Context context);
	T translate(AST.LTL.UntilLTL ast, Types.Context context);
	T translate(AST.LTL.WeakUntilLTL ast, Types.Context context);
	
	default public T preprocess(AST.LTL ast, Types.Context context) 
	{
	  if (ast instanceof AST.LTL.StateLTL) return translate((AST.LTL.StateLTL)ast, context);
	  if (ast instanceof AST.LTL.ActionLTL) return translate((AST.LTL.ActionLTL)ast, context);
	  if (ast instanceof AST.LTL.NotLTL) return translate((AST.LTL.NotLTL)ast, context);
	  if (ast instanceof AST.LTL.AndLTL) return translate((AST.LTL.AndLTL)ast, context);
	  if (ast instanceof AST.LTL.OrLTL) return translate((AST.LTL.OrLTL)ast, context);
	  if (ast instanceof AST.LTL.ImpliesLTL) return translate((AST.LTL.ImpliesLTL)ast, context);
	  if (ast instanceof AST.LTL.EquivLTL) return translate((AST.LTL.EquivLTL)ast, context);
	  if (ast instanceof AST.LTL.IfThenElseLTL) return translate((AST.LTL.IfThenElseLTL)ast, context);
	  if (ast instanceof AST.LTL.NextLTL) return translate((AST.LTL.NextLTL)ast, context);
	  if (ast instanceof AST.LTL.GloballyLTL) return translate((AST.LTL.GloballyLTL)ast, context);
	  if (ast instanceof AST.LTL.FinallyLTL) return translate((AST.LTL.FinallyLTL)ast, context);
	  if (ast instanceof AST.LTL.UntilLTL) return translate((AST.LTL.UntilLTL)ast, context);
	  if (ast instanceof AST.LTL.WeakUntilLTL) return translate((AST.LTL.WeakUntilLTL)ast, context);
	  if (ast instanceof AST.LTL.ForallLTL) return translate((AST.LTL.ForallLTL)ast, context);
	  if (ast instanceof AST.LTL.ExistsLTL) return translate((AST.LTL.ExistsLTL)ast, context);
	  if (ast instanceof AST.LTL.LetLTL) return translate((AST.LTL.LetLTL)ast, context);
	  if (ast instanceof AST.LTL.LetParLTL) return translate((AST.LTL.LetParLTL)ast, context);
	  return null;
	}
}
// ----------------------------------------------------------------------------
// end of file
// ----------------------------------------------------------------------------
