// ---------------------------------------------------------------------------
// AutomatonNode.java
// A node of the LTL formula automaton.
// $Id: AutomatonNode.java,v 1.1 2022/08/24 12:47:14 schreine Exp $
//
// Author: Ágoston Sütő <agoston.suetoe@jku.at>
// Copyright (C) 2021-, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.jku.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package riscal.ltl.automaton;

import riscal.ltl.LTLChecker;
import riscal.ltl.LTLFormula;
import riscal.semantics.Systems;

import java.util.List;

public class AutomatonNode {

	public List<AutomatonNode> children;
	public List<LTLFormula> formulas;
	// bitset, the i-th bit being set means this node is part of
	// the i-th final set of the automaton
	public long finalStates;

	public boolean isCompatibleWith(LTLChecker ltlChecker, Systems.StateClass systemState) {
		for (LTLFormula formula : formulas) {
			if (!formula.isCompatibleWith(systemState, ltlChecker)) {
				return false;
			}
		}
		return true;
	}
}
// ----------------------------------------------------------------------------
// end of file
// ----------------------------------------------------------------------------
