// ---------------------------------------------------------------------------
// RISCTPOptions.java
// The options used for the RISCTP theorem proving interface.
// $Id: RISCTPOptions.java,v 1.5 2022/07/08 10:57:38 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.jku.at>
// Copyright (C) 2022-, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, https://www.risc.jku.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package riscal.risctp;

import risctp.smt.*;

public class RISCTPOptions
{
  // current values for configuration
  private static Boolean methodSMT = null;
  private static Boolean methodFOL = null;
  private static String execPathZ3 = null;
  private static String execPathCVC5 = null;
  private static String execPathVampire = null;
  private static Integer mode = null;
  private static Integer timeout = null;
  
  // the corresponding getter and setter methods
  public static Boolean getMethodSMT() { return methodSMT; }
  public static Boolean getMethodFOL() { return methodFOL; }
  public static Boolean getSolverZ3() { return Solver.getSolverType() == Solver.SolverType.Z3; }
  public static Boolean getSolverCVC5() { return Solver.getSolverType() == Solver.SolverType.CVC5; }
  public static Boolean getSolverVampire() { return Solver.getSolverType() == Solver.SolverType.VAMPIRE; }
  public static String getExecPathZ3() { return execPathZ3; }
  public static String getExecPathCVC5() { return execPathCVC5; }
  public static String getExecPathVampire() { return execPathVampire; }
  public static Integer getMode() { return mode; }
  public static Integer getTimeout() { return timeout; }
  
  // the corresponding setter methods
  public static void setMethodSMT(Boolean val) { methodSMT = val; }
  public static void setMethodFOL(Boolean val) { methodFOL = val; }
  public static void setSolverZ3() { Solver.configure(Solver.SolverType.Z3); }
  public static void setSolverCVC5() { Solver.configure(Solver.SolverType.CVC5); }
  public static void setSolverVampire() { Solver.configure(Solver.SolverType.VAMPIRE); }
  public static void setExecPathZ3(String val) { execPathZ3 = val; }
  public static void setExecPathCVC5(String val) { execPathCVC5 = val; }
  public static void setExecPathVampire(String val) { execPathVampire = val; }
  public static void setMode(Integer val) { mode = val; }
  public static void setTimeout(Integer val) { timeout = val; }
  
  // default values for configuration
  private final static boolean methodSMTDefault = true;
  private final static boolean methodFOLDefault = false;
  private final static int modeDefault = 1;
  private final static int timeoutDefault = 5000;
  
  // initialize the options
  static { set(); }
  
  // set the theorem proving options
  private static void set()
  {
    if (methodSMT == null) methodSMT = methodSMTDefault;
    if (methodFOL == null) methodFOL = methodFOLDefault;
    if (execPathZ3 == null) execPathZ3 = "z3";  
    if (execPathCVC5 == null) execPathCVC5 = "cvc5"; 
    if (execPathVampire == null) execPathVampire = "vampire"; 
    if (mode == null) mode = modeDefault;
    if (timeout == null) timeout = timeoutDefault;
  }
  
  // reset some theorem proving options to their defaults
  public static void reset()
  {
    methodSMT = null;
    methodFOL = null;
    mode = null;
    timeout = null;
    set();
  }  
}
// ---------------------------------------------------------------------------
// end of file
// ---------------------------------------------------------------------------